@@ -209,9 +209,20 @@ void SCH_COMMIT::pushSchEdit( const wxString& aMessage, int aCommitFlags )
             schematic = schItem->Schematic();
 
         if( schItem->IsSelected() )
+        {
             selectedModified = true;
+        }
+        else
+        {
+            schItem->RunOnChildren(
+                    [&selectedModified]( SCH_ITEM* aChild )
+                    {
+                        if( aChild->IsSelected() )
+                            selectedModified = true;
+                    } );
+        }
 
-        auto updateConnectivityFlag = [&, this]()
+        auto updateConnectivityFlag = [&]()
         {
             if( schItem->IsConnectable() )
             {
