@@ -3,7 +3,7 @@
  *
  * Copyright (C) 2017 Jean-Pierre Charras, jp.charras at wanadoo.fr
  * Copyright (C) 2011 Wayne Stambaugh <stambaughw@gmail.com>
- * Copyright (C) 1992-2023 KiCad Developers, see AUTHORS.txt for contributors.
+ * Copyright (C) 1992-2023, 2024 KiCad Developers, see AUTHORS.txt for contributors.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -23,6 +23,7 @@
  * 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
  */
 
+#include <refdes_utils.h>
 #include <sch_screen.h>
 #include <sch_item.h>
 #include <sch_marker.h>
@@ -149,9 +150,10 @@ SCH_SHEET_PATH SCH_SHEET_PATH::operator+( const SCH_SHEET_PATH& aOther )
 
 void SCH_SHEET_PATH::initFromOther( const SCH_SHEET_PATH& aOther )
 {
-    m_sheets            = aOther.m_sheets;
-    m_virtualPageNumber = aOther.m_virtualPageNumber;
-    m_current_hash      = aOther.m_current_hash;
+    m_sheets             = aOther.m_sheets;
+    m_virtualPageNumber  = aOther.m_virtualPageNumber;
+    m_current_hash       = aOther.m_current_hash;
+    m_cached_page_number = aOther.m_cached_page_number;
 
     // Note: don't copy m_recursion_test_cache as it is slow and we want SCH_SHEET_PATHS to be
     // very fast to construct for use in the connectivity algorithm.
@@ -290,6 +292,7 @@ wxString SCH_SHEET_PATH::PathAsString() const
 KIID_PATH SCH_SHEET_PATH::Path() const
 {
     KIID_PATH path;
+    path.reserve( m_sheets.size() );
 
     for( const SCH_SHEET* sheet : m_sheets )
         path.push_back( sheet->m_Uuid );
@@ -397,11 +400,9 @@ void SCH_SHEET_PATH::AppendSymbol( SCH_REFERENCE_LIST& aReferences, SCH_SYMBOL*
     // affects power symbols.
     if( aIncludePowerSymbols || aSymbol->GetRef( this )[0] != wxT( '#' ) )
     {
-        LIB_SYMBOL* symbol = aSymbol->GetLibSymbolRef().get();
-
-        if( symbol || aForceIncludeOrphanSymbols )
+        if( aSymbol->GetLibSymbolRef() || aForceIncludeOrphanSymbols )
         {
-            SCH_REFERENCE schReference( aSymbol, symbol, *this );
+            SCH_REFERENCE schReference( aSymbol, *this );
 
             schReference.SetSheetNumber( m_virtualPageNumber );
             aReferences.AddItem( schReference );
@@ -434,7 +435,7 @@ void SCH_SHEET_PATH::AppendMultiUnitSymbol( SCH_MULTI_UNIT_REFERENCE_MAP& aRefLi
 
     if( symbol && symbol->GetUnitCount() > 1 )
     {
-        SCH_REFERENCE schReference = SCH_REFERENCE( aSymbol, symbol, *this );
+        SCH_REFERENCE schReference = SCH_REFERENCE( aSymbol, *this );
         schReference.SetSheetNumber( m_virtualPageNumber );
         wxString reference_str = schReference.GetRef();
 
@@ -539,8 +540,7 @@ wxString SCH_SHEET_PATH::GetPageNumber() const
 
     wxCHECK( sheet, wxEmptyString );
 
-    SCH_SHEET_PATH tmpPath = *this;
-
+    KIID_PATH tmpPath = Path();
     tmpPath.pop_back();
 
     return sheet->getPageNumber( tmpPath );
@@ -553,7 +553,7 @@ void SCH_SHEET_PATH::SetPageNumber( const wxString& aPageNumber )
 
     wxCHECK( sheet, /* void */ );
 
-    SCH_SHEET_PATH tmpPath = *this;
+    KIID_PATH tmpPath = Path();
 
     tmpPath.pop_back();
 
@@ -562,8 +562,11 @@ void SCH_SHEET_PATH::SetPageNumber( const wxString& aPageNumber )
 }
 
 
-void SCH_SHEET_PATH::AddNewSymbolInstances( const SCH_SHEET_PATH& aPrefixSheetPath )
+void SCH_SHEET_PATH::AddNewSymbolInstances( const SCH_SHEET_PATH& aPrefixSheetPath,
+                                            const wxString& aProjectName )
 {
+    wxCHECK( !aProjectName.IsEmpty(), /* void */ );
+
     SCH_SHEET_PATH newSheetPath( aPrefixSheetPath );
     SCH_SHEET_PATH currentSheetPath( *this );
 
@@ -580,12 +583,16 @@ void SCH_SHEET_PATH::AddNewSymbolInstances( const SCH_SHEET_PATH& aPrefixSheetPa
 
         if( symbol->GetInstance( newSymbolInstance, Path(), true ) )
         {
+            newSymbolInstance.m_ProjectName = aProjectName;
             // Use an existing symbol instance for this path if it exists.
+
             newSymbolInstance.m_Path = newSheetPath.Path();
             symbol->AddHierarchicalReference( newSymbolInstance );
         }
         else if( !symbol->GetInstances().empty() )
         {
+            newSymbolInstance.m_ProjectName = aProjectName;
+
             // Use the first symbol instance if any symbol instance data exists.
             newSymbolInstance = symbol->GetInstances()[0];
             newSymbolInstance.m_Path = newSheetPath.Path();
@@ -593,6 +600,8 @@ void SCH_SHEET_PATH::AddNewSymbolInstances( const SCH_SHEET_PATH& aPrefixSheetPa
         }
         else
         {
+            newSymbolInstance.m_ProjectName = aProjectName;
+
             // Fall back to the last saved symbol field and unit settings if there is no
             // instance data.
             newSymbolInstance.m_Path = newSheetPath.Path();
@@ -622,6 +631,33 @@ void SCH_SHEET_PATH::RemoveSymbolInstances( const SCH_SHEET_PATH& aPrefixSheetPa
 }
 
 
+void SCH_SHEET_PATH::CheckForMissingSymbolInstances( const wxString& aProjectName )
+{
+    wxCHECK( !aProjectName.IsEmpty() && LastScreen(), /* void */ );
+
+    for( SCH_ITEM* item : LastScreen()->Items().OfType( SCH_SYMBOL_T ) )
+    {
+        SCH_SYMBOL* symbol = static_cast<SCH_SYMBOL*>( item );
+
+        wxCHECK2( symbol, continue );
+
+        SCH_SYMBOL_INSTANCE symbolInstance;
+
+        if( !symbol->GetInstance( symbolInstance, Path() ) )
+        {
+            wxLogTrace( traceSchSheetPaths, "Adding missing symbol \"%s\" instance data for "
+                        "sheet path '%s'.",
+                        symbol->m_Uuid.AsString(), PathHumanReadable( false ) );
+
+            symbolInstance.m_Reference = UTIL::GetRefDesUnannotated( symbol->GetPrefix() );
+            symbolInstance.m_ProjectName = aProjectName;
+            symbolInstance.m_Path = Path();
+            symbol->AddHierarchicalReference( symbolInstance );
+        }
+    }
+}
+
+
 void SCH_SHEET_PATH::MakeFilePathRelativeToParentSheet()
 {
     wxCHECK( m_sheets.size() > 1, /* void */  );
@@ -732,17 +768,27 @@ void SCH_SHEET_LIST::BuildSheetList( SCH_SHEET* aSheet, bool aCheckIntegrity )
 
 void SCH_SHEET_LIST::SortByPageNumbers( bool aUpdateVirtualPageNums )
 {
+    for( const SCH_SHEET_PATH& path : *this )
+        path.CachePageNumber();
+
     std::sort( begin(), end(),
-        []( SCH_SHEET_PATH a, SCH_SHEET_PATH b ) -> bool
+        []( const SCH_SHEET_PATH& a, const SCH_SHEET_PATH& b ) -> bool
         {
-            int retval = a.ComparePageNum( b );
+            int retval = SCH_SHEET::ComparePageNum( a.GetCachedPageNumber(),
+                                                    b.GetCachedPageNumber() );
 
             if( retval < 0 )
                 return true;
             else if( retval > 0 )
                 return false;
-            else /// Enforce strict ordering.  If the page numbers are the same, use UUIDs
-                return a.GetCurrentHash() < b.GetCurrentHash();
+
+            if( a.GetVirtualPageNumber() < b.GetVirtualPageNumber() )
+                return true;
+            else if( a.GetVirtualPageNumber() > b.GetVirtualPageNumber() )
+                return false;
+
+            /// Enforce strict ordering.  If the page numbers are the same, use UUIDs
+            return a.GetCurrentHash() < b.GetCurrentHash();
         } );
 
     if( aUpdateVirtualPageNums )
@@ -750,9 +796,7 @@ void SCH_SHEET_LIST::SortByPageNumbers( bool aUpdateVirtualPageNums )
         int virtualPageNum = 1;
 
         for( SCH_SHEET_PATH& sheet : *this )
-        {
             sheet.SetVirtualPageNumber( virtualPageNum++ );
-        }
     }
 }
 
@@ -900,7 +944,7 @@ void SCH_SHEET_LIST::AnnotatePowerSymbols()
 
             if( libSymbol && libSymbol->IsPower() )
             {
-                SCH_REFERENCE schReference( symbol, libSymbol, sheet );
+                SCH_REFERENCE schReference( symbol, sheet );
                 references.AddItem( schReference );
             }
         }
@@ -1237,10 +1281,11 @@ void SCH_SHEET_LIST::SetInitialPageNumbers()
 }
 
 
-void SCH_SHEET_LIST::AddNewSymbolInstances( const SCH_SHEET_PATH& aPrefixSheetPath )
+void SCH_SHEET_LIST::AddNewSymbolInstances( const SCH_SHEET_PATH& aPrefixSheetPath,
+                                            const wxString& aProjectName )
 {
     for( SCH_SHEET_PATH& sheetPath : *this )
-        sheetPath.AddNewSymbolInstances( aPrefixSheetPath );
+        sheetPath.AddNewSymbolInstances( aPrefixSheetPath, aProjectName );
 }
 
 
@@ -1276,7 +1321,7 @@ void SCH_SHEET_LIST::AddNewSheetInstances( const SCH_SHEET_PATH& aPrefixSheetPat
 
     for( SCH_SHEET_PATH& sheetPath : *this )
     {
-        SCH_SHEET_PATH tmp( sheetPath );
+        KIID_PATH tmp = sheetPath.Path();
         SCH_SHEET_PATH newSheetPath( aPrefixSheetPath );
 
         // Prefix the new hierarchical path.
@@ -1294,10 +1339,10 @@ void SCH_SHEET_LIST::AddNewSheetInstances( const SCH_SHEET_PATH& aPrefixSheetPat
         SCH_SHEET_INSTANCE instance;
 
         // Add the instance if it doesn't already exist
-        if( !sheet->getInstance( instance, tmp.Path(), true ) )
+        if( !sheet->getInstance( instance, tmp, true ) )
         {
             sheet->addInstance( tmp );
-            sheet->getInstance( instance, tmp.Path(), true );
+            sheet->getInstance( instance, tmp, true );
         }
 
         // Get a new page number if we don't have one
@@ -1321,6 +1366,13 @@ void SCH_SHEET_LIST::AddNewSheetInstances( const SCH_SHEET_PATH& aPrefixSheetPat
 }
 
 
+void SCH_SHEET_LIST::CheckForMissingSymbolInstances( const wxString& aProjectName )
+{
+    for( SCH_SHEET_PATH& sheetPath : *this )
+        sheetPath.CheckForMissingSymbolInstances( aProjectName );
+}
+
+
 int SCH_SHEET_LIST::GetLastVirtualPageNumber() const
 {
     int lastVirtualPageNumber = 1;
