@@ -196,7 +196,7 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
                 // Then we need to annotate all instances by sheet
                 for( SCH_SHEET_PATH& instance : newInstances )
                 {
-                    SCH_REFERENCE newReference( symbol, symbol->GetLibSymbolRef().get(), instance );
+                    SCH_REFERENCE newReference( symbol, instance );
                     SCH_REFERENCE_LIST refs;
                     refs.AddItem( newReference );
 
@@ -308,7 +308,13 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
                 SYMBOL_LIB_TABLE* libs = PROJECT_SCH::SchSymbolLibTable( &m_frame->Prj() );
                 SYMBOL_LIB*       cache = PROJECT_SCH::SchLibs( &m_frame->Prj() )->GetCacheLibrary();
 
-                std::vector<LIB_SYMBOL*> part_list;
+                auto compareByLibID =
+                        []( const LIB_SYMBOL* aFirst, const LIB_SYMBOL* aSecond ) -> bool
+                        {
+                            return aFirst->LibId().Format() < aSecond->LibId().Format();
+                        };
+
+                std::set<LIB_SYMBOL*, decltype( compareByLibID )> part_list( compareByLibID );
 
                 for( SCH_SHEET_PATH& sheet : sheets )
                 {
@@ -321,15 +327,12 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
                         LIB_SYMBOL* libSymbol = SchGetLibSymbol( s->GetLibId(), libs, cache );
 
                         if( libSymbol )
-                            part_list.push_back( libSymbol );
+                            part_list.insert( libSymbol );
                     }
                 }
 
-                // Remove redundant parts
-                sort( part_list.begin(), part_list.end() );
-                part_list.erase( unique( part_list.begin(), part_list.end() ), part_list.end() );
-
                 std::vector<PICKED_SYMBOL> alreadyPlaced;
+
                 for( LIB_SYMBOL* libSymbol : part_list )
                 {
                     PICKED_SYMBOL pickedSymbol;
@@ -370,8 +373,7 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
                 annotate();
 
                 // Update the list of references for the next symbol placement.
-                SCH_REFERENCE placedSymbolReference( symbol, symbol->GetLibSymbolRef().get(),
-                                                     m_frame->GetCurrentSheet() );
+                SCH_REFERENCE placedSymbolReference( symbol, m_frame->GetCurrentSheet() );
                 existingRefs.AddItem( placedSymbolReference );
                 existingRefs.SortByReferenceOnly();
 
@@ -433,9 +435,7 @@ int SCH_DRAWING_TOOLS::PlaceSymbol( const TOOL_EVENT& aEvent )
                         annotate();
 
                         // Update the list of references for the next symbol placement.
-                        SCH_REFERENCE placedSymbolReference( symbol,
-                                                             symbol->GetLibSymbolRef().get(),
-                                                             m_frame->GetCurrentSheet() );
+                        SCH_REFERENCE placedSymbolReference( symbol, m_frame->GetCurrentSheet() );
                         existingRefs.AddItem( placedSymbolReference );
                         existingRefs.SortByReferenceOnly();
                     }
@@ -1248,8 +1248,11 @@ SCH_TEXT* SCH_DRAWING_TOOLS::createNewText( const VECTOR2I& aPosition, int aType
 
     textItem->SetParent( schematic );
 
+    textItem->SetTextSize( VECTOR2I( settings.m_DefaultTextSize, settings.m_DefaultTextSize ) );
+
     if( aType != LAYER_NETCLASS_REFS )
     {
+        // Must be after SetTextSize()
         textItem->SetBold( m_lastTextBold );
         textItem->SetItalic( m_lastTextItalic );
     }
@@ -1265,7 +1268,6 @@ SCH_TEXT* SCH_DRAWING_TOOLS::createNewText( const VECTOR2I& aPosition, int aType
         textItem->SetTextAngle( m_lastTextAngle );
     }
 
-    textItem->SetTextSize( VECTOR2I( settings.m_DefaultTextSize, settings.m_DefaultTextSize ) );
     textItem->SetFlags( IS_NEW | IS_MOVING );
 
     if( !labelItem )
@@ -1862,10 +1864,13 @@ int SCH_DRAWING_TOOLS::DrawShape( const TOOL_EVENT& aEvent )
             {
                 SCH_TEXTBOX* textbox = new SCH_TEXTBOX( 0, m_lastTextboxFillStyle );
 
-                textbox->SetBold( m_lastTextBold );
-                textbox->SetItalic( m_lastTextItalic );
                 textbox->SetTextSize( VECTOR2I( sch_settings.m_DefaultTextSize,
                                                 sch_settings.m_DefaultTextSize ) );
+
+                // Must come after SetTextSize()
+                textbox->SetBold( m_lastTextBold );
+                textbox->SetItalic( m_lastTextItalic );
+
                 textbox->SetTextAngle( m_lastTextboxAngle );
                 textbox->SetHorizJustify( m_lastTextboxHJustify );
                 textbox->SetVertJustify( m_lastTextboxVJustify );
