@@ -33,6 +33,7 @@
 #include <font/glyph.h>
 #include <font/text_attributes.h>
 
+
 class OUTPUTFORMATTER;
 class SHAPE_COMPOUND;
 class SHAPE_POLY_SET;
@@ -60,11 +61,6 @@ namespace KIFONT
 using KIGFX::RENDER_SETTINGS;
 using KIGFX::COLOR4D;
 
-// part of the kicad_plugin.h family of defines.
-// See kicad_plugin.h for the choice of the value
-// When set when calling  EDA_TEXT::Format, disable writing the "hide" keyword in save file
-#define CTL_OMIT_HIDE               (1 << 6)
-
 
 /**
  * This is the "default-of-the-default" hardcoded text size; individual application define their
@@ -144,6 +140,7 @@ public:
     bool IsItalic() const                       { return m_attributes.m_Italic; }
 
     void SetBold( bool aBold );
+    void SetBoldFlag( bool aBold );
     bool IsBold() const                         { return m_attributes.m_Bold; }
 
     virtual void SetVisible( bool aVisible );
@@ -348,7 +345,8 @@ public:
                     const VECTOR2I& aOffset = { 0, 0 } ) const;
 
     // Support for reading the cache from disk.
-    void SetupRenderCache( const wxString& aResolvedText, const EDA_ANGLE& aAngle );
+    void SetupRenderCache( const wxString& aResolvedText, const KIFONT::FONT* aFont,
+                           const EDA_ANGLE& aAngle, const VECTOR2I& aOffset );
     void AddRenderCacheGlyph( const SHAPE_POLY_SET& aPoly );
 
     int Compare( const EDA_TEXT* aOther ) const;
